# Suppress output of debuginfo and debugsource
%global debug_package %{nil}

%global git     %{nil}
                #.git3cadeb5

Name:           arexibo
Version:        0.3.0
Release:        3%{?git}%{?dist}
Summary:        A Rust Linux Xibo player

License:        AGPLv3+
    
URL:            https://github.com/birkenfeld/arexibo
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}%{git}.tar.gz

%if 0%{?fedora} || 0%{?rhel} >= 8
ExclusiveArch:  %{rust_arches}
%else
ExclusiveArch:  x86_64 ppc64le aarch64
%endif
BuildRequires:  rust >= 1.75
BuildRequires:  cargo
BuildRequires:  gcc-c++
BuildRequires:  dbus-devel >= 1.6
BuildRequires:  qt6-qtwebengine-devel
BuildRequires:  zeromq-devel >= 4.1
BuildRequires:  systemd

Requires:       qt6-qtwebengine
Requires:       xorg-x11-server-Xorg
Requires:       xorg-x11-xinit
%if 0%{?fedora} || 0%{?rhel} >= 8
Recommends:     ffmpeg
%endif

Requires(pre): /usr/bin/getent
Requires(pre): /usr/sbin/groupadd
Requires(pre): /usr/sbin/useradd

Requires(post):   systemd
Requires(preun):  systemd

Requires(postun): systemd

%description
Arexibo is an unofficial alternate Digital Signage Player for Xibo,
implemented in Rust with the GTK GUI components, for Linux platforms.

It is currently quite incomplete.
Don't expect any particular feature to work unless tested.


%prep
%setup -q -n %{name}-%{version}%{git}

cat >x11 <<EOF
allowed_users = anybody
EOF

cat >systemd <<EOF
[Unit]
Description=Start X with Arexibo player
After=network-online.target
Requires=network-online.target

[Service]
Type=simple
ExecStart=%{_bindir}/xinit %{_bindir}/%{name} %{_localstatedir}/lib/xibo -- :0 vt2 -s 0 -v -dpms
User=xibo
Group=xibo
Restart=always
RestartSec=60
Environment=NO_AT_BRIDGE=1

[Install]
WantedBy=multi-user.target
EOF

%build
cargo fetch
cargo build --release --offline -j2

%install
mkdir -p %{buildroot}%{_bindir}
install -Dpm 0755 target/release/%{name} %{buildroot}%{_bindir}/

# xibo datas
mkdir -p %{buildroot}%{_localstatedir}/lib/xibo

# x11 wrapper
mkdir -p %{buildroot}%{_sysconfdir}/X11
install -Dpm 0644 x11 %{buildroot}%{_sysconfdir}/X11/Xwrapper.config

# systemd
install -Dpm 0644 systemd %{buildroot}%{_unitdir}/%{name}.service

%pre
getent group xibo >/dev/null || groupadd -g 9505 -r xibo
getent passwd xibo >/dev/null || \
  useradd -r -u 9505 -g xibo -d %{_localstatedir}/lib/xibo -s /sbin/nologin \
    -c "Xibo client user" xibo

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%license LICENSE
%doc CHANGELOG.md README.md assets target/release/examples
%attr(0750,xibo,xibo) %dir %{_localstatedir}/lib/xibo
%{_bindir}/%{name}
%{_sysconfdir}/X11/Xwrapper.config
%{_unitdir}/%{name}.service

%changelog
* Sat Apr 05 2025 Jean-Marc Liger <ligenix@iscp.fr> - 0.3.0-3
- Add xorg-x11-* dependencies for minimal install without GUI
- Move xibo home directory to /var/lib/xibo and fix permissions

* Wed Apr 02 2025 Jean-Marc Liger <ligenix@iscp.fr> - 0.3.0-2
- Remove gstreamer1 dependencies
- Recommend ffmpeg

* Sat Mar 29 2025 Jean-Marc Liger <ligenix@iscp.fr> - 0.3.0-1
- Update to 0.3.0
  Switch GUI to QWebEngine implementation

* Tue Feb 18 2025 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.8-1
- Update to 0.2.8

* Mon Feb 03 2025 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.7-1
- Update to 0.2.7
  Rust toolchain >= 1.75 is required

* Tue Aug 13 2024 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.5-2
- Add missing /var/cache/xibo

* Tue Aug 13 2024 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.5-1
- Update to 0.2.5

* Sat Jul 20 2024 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.4-1
- Update to 0.2.4

* Wed Dec 27 2023 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.3-4.3cadeb5
- Update from last git commit 3cadeb5
  Rust toolchain >= 1.66 is required

* Tue Aug 15 2023 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.3-3
- Add gstreamer1-plugin-openh264 dependency #Luc Tamisier

* Sat Nov 19 2022 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.3-2
- Add gstreamer1 dependencies #Nicolas Meneceur
- Update cargo dependencies from git

* Sat Nov 12 2022 Jean-Marc Liger <ligenix@iscp.fr> - 0.2.3-1
- Initial RPM 0.2.3
